@@ -85,7 +85,7 @@ class CfwClient(AbstractClient):
 
 
     def CreateAcRules(self, request):
-        """创建规则
+        """创建访问控制规则
 
         :param request: Request instance for CreateAcRules.
         :type request: :class:`tencentcloud.cfw.v20190904.models.CreateAcRulesRequest`
@@ -1303,10 +1303,10 @@ class CfwClient(AbstractClient):
 
 
     def ModifyBlockIgnoreList(self, request):
-        """支持对拦截列表、忽略列表如下操作：
-        批量增加拦截IP、忽略IP/域名
-        批量删除拦截IP、忽略IP/域名
-        批量修改拦截IP、忽略IP/域名生效事件
+        """支持对封禁列表、放通列表如下操作：
+        批量增加封禁IP、放通IP/域名
+        批量删除封禁IP、放通IP/域名
+        批量修改封禁IP、放通IP/域名生效事件
 
         :param request: Request instance for ModifyBlockIgnoreList.
         :type request: :class:`tencentcloud.cfw.v20190904.models.ModifyBlockIgnoreListRequest`
